Available on crate feature
alloc only.Expand description
Low level memory allocation.
Structs
- A structure of function pointers making up an allocator VTable.
Enums
- Describes an error returned from allocation functions.
Statics
nstd’s default allocator.
Functions
- Allocates a block of memory on the heap. The number of bytes to be allocated is specified by
size. - Allocates a block of zero-initialized memory on the heap.
- Deallocates a block of memory previously allocated by
nstd_alloc_allocate[_zeroed]. - Reallocates a block of memory previously allocated by
nstd_alloc_allocate[_zeroed].