Available on crate feature
core only.Expand description
Unowned C string slices.
Modules
- Raw C string processing.
Structs
- An immutable slice of a C string.
- A mutable slice of a C string.
Functions
- Returns a byte slice of a C string slice’s data.
- Returns a pointer to the first character in a C string slice.
- Returns a pointer to the first character in a C string slice, or null if it is empty.
- Creates a new instance of
NSTDCStrfrom a raw C string, excluding the null byte. - Creates a new instance of
NSTDCStrfrom a raw C string, including the null byte. - Return a pointer to the character at index
posincstr. - Returns a pointer to the first null byte in a C string slice if one is present.
- Determines whether or not a C string slice is null terminated. This will return false if the C string slice contains any null bytes before the last byte.
- Returns a pointer to the last character in a C string slice, or null if it is empty.
- Returns the length of a C string slice.
- Returns a byte slice of a C string slice’s data.
- Creates an immutable version of a mutable C string slice.
- Returns a pointer to the first character in a C string slice.
- Returns a pointer to the first character in a C string slice.
- Returns a pointer to the first character in a C string slice, or null if it is empty.
- Returns an immutable pointer to the first character in a C string slice, or null if it is empty.
- Creates a new instance of
NSTDCStrMutfrom a raw C string, excluding the null byte. - Creates a new instance of
NSTDCStrMutfrom a raw C string, including the null byte. - Return a pointer to the character at index
posincstr. - Return an immutable pointer to the character at index
posincstr. - Returns a pointer to the first null byte in a C string slice if one is present.
- Returns an immutable pointer to the first null byte in a C string slice if one is present.
- Determines whether or not a C string slice is null terminated. This will return false if the C string slice contains any null bytes before the last byte.
- Returns a pointer to the last character in a C string slice, or null if it is empty.
- Returns an immutable pointer to the last character in a C string slice, or null if it is empty.
- Returns the length of a C string slice.
- Creates a new C string slice from a raw pointer and a size.
- Creates a new C string slice from a raw pointer and a size without checking if
rawis null. - Creates a new C string slice from a raw pointer and a size.
- Creates a new C string slice from a raw pointer and a size without checking if
rawis null.
Type Aliases
- Represents an optional value of type
NSTDCStr. - Represents an optional value of type
NSTDCStrMut.