Available on crate feature
core only.Expand description
Raw C string processing.
Functions
- Compares two raw null-terminated C strings, returning
NSTD_TRUEif they are lexicographically equal. - Copies the contents of one raw C string to another, excluding the source’s null-terminator.
- Copies the contents of one raw C string to another, including the source’s null-terminator.
- Gets the length of a raw null terminated C string, not counting the C string’s null byte.
- Gets the length of a raw null terminated C string, counting the C string’s null byte.