Struct nstd_sys::core::cstr::NSTDCStrMut
source · #[repr(C)]pub struct NSTDCStrMut { /* private fields */ }Available on crate feature
nstd_core only.Expand description
A mutable slice of a C string.
Safety
The user of this structure must ensure that the pointed-to data remains valid, unmodified, and unreferenced in any other code while an instance of this structure is in use, else data races may occur.