Function nstd_sys::core::nstd_core_panic

source ·
#[no_mangle]
pub const extern "C" fn nstd_core_panic() -> !
Available on crate feature core only.
Invokes the runtime’s panic handler.

This operation will never return.

In contrast to nstd_core_abort, which will terminate the program immediately, this method of abortion will begin unwinding the stack (when panic = “unwind”). This can be useful for Rust programs that don’t unwind through call frames from foreign languages.

Panics

This function will always panic.