#[no_mangle]
pub const unsafe extern "C" fn nstd_core_panic_with_msg(
    msg: &NSTDStr
) -> !
Available on crate feature core only.
Invokes the runtime’s panic handler with a UTF-8 encoded payload.

This operation will never return.

In contrast to nstd_core_abort_with_msg, which will terminate the program immediately, this method of abortion will begin unwinding the stack (when panic = “unwind”). This can be useful for Rust programs that don’t unwind through call frames from foreign languages.

Parameters:

  • const NSTDStr *msg - The message to panic with.

Panics

This function will always panic.

Safety

msg’s data must be valid for reads.