Module nstd_sys::core::ops

source ·
Available on crate feature core only.
Operator overloading for types and operators that may cause overflow.

The types of overflows that this module attempts to catch can be found here.

Also see this issue for more information.

Functions