Available on crate feature
core only.Expand description
A sized pointer to some arbitrary type.
Modules
- Provides useful utilities for working with raw pointers.
Structs
- A sized immutable pointer to some arbitrary type.
- A sized pointer to some arbitrary type.
Functions
- Returns a raw immutable pointer to the object pointed to by
ptr. - Creates an immutable version of a mutable pointer.
- Returns a raw pointer to the object pointed to by
ptr. - Returns a raw immutable pointer to the object pointed to by
ptr. - Creates a new instance of
NSTDPtrMut. - Creates a new instance of
NSTDPtrMutwithout checking ifobjis null. - Returns the size of the object being pointed to.
- Writes data from
objtoptr. The number of bytes written is determined byptr.size. - Creates a new instance of
NSTDPtr. - Creates a new instance of
NSTDPtrwithout checking ifobjis null. - Returns the size of the object being pointed to.
Type Aliases
- Represents an optional value of type
NSTDPtr. - Represents an optional value of type
NSTDPtrMut.