Available on crate feature
core only.Expand description
Provides useful utilities for working with raw pointers.
Functions
- Returns a pointer that is properly aligned to
alignbased on the offsetptr. - Returns a pointer that is properly aligned to
alignbased on the offsetptr. - Creates a new dangling pointer to some immutable memory. The pointer is guaranteed to have valid alignment for any scalar type.
- Creates a new dangling pointer to some mutable memory. The pointer is guaranteed to have valid alignment for any scalar type.
- Checks if
ptris aligned toalign.