#[repr(C)]pub struct NSTDPtr { /* private fields */ }Available on crate feature
nstd_core only.Expand description
A sized immutable pointer to some arbitrary type.
Safety
The user of this structure must ensure that the pointed-to data remains valid and unmodified while an instance of this structure is in use.