Struct nstd_sys::core::ptr::NSTDPtrMut
source · #[repr(C)]pub struct NSTDPtrMut { /* private fields */ }Available on crate feature
nstd_core only.Expand description
A sized pointer to some arbitrary type.
Safety
The user of this structure must ensure that the pointed-to data remains valid, unmodified, and unreferenced in any other code while an instance of this structure is in use, else data races may occur.