#[repr(u8)]
#[repr(C)]
pub enum NSTDResult<T, E> { Err(E), Ok(T), }
Available on crate feature core only.
Defines a “result” type with success and error variants.

Variants



Err(E)

The error variant.



Ok(T)

The success variant.

Implementations

source

impl<T, E> NSTDResult<T, E>

source

pub fn unwrap(self) -> T

Attempts to return the contained Ok value in an NSTDResult.

This operation is only useful for testing code, it’s use in production should be discouraged.

Panics

Panics if self is an Err value.

source

pub fn expect(self, msg: &str) -> T

Attempts to return the contained Ok value in an NSTDResult.

Panics

Panics with msg if self is an Err value.