Available on crate feature
core only.Expand description
A view into a sequence of values in memory.
Structs
- An immutable view into a sequence of values in memory.
- A view into a sequence of values in memory.
Functions
- Returns a raw pointer to the slice’s memory.
- Creates a new empty slice with a given
stride. - Returns an immutable pointer to the first element in the slice.
- Returns an immutable pointer to the element at index
posinslice. - Returns an immutable pointer to the last element in the slice.
- Returns the number of elements in an immutable slice.
- Creates an immutable version of a mutable slice.
- Returns a raw pointer to the slice’s memory.
- Returns an immutable raw pointer to the slice’s memory.
- Copies data into
destfromsrc. The number of bytes copied is determined bysrc. - Creates a new empty slice with a given
stride. - Returns a pointer to the first element in the slice.
- Returns an immutable pointer to the first element in the slice.
- Returns a pointer to the element at index
posinslice. - Returns an immutable pointer to the element at index
posinslice. - Returns a pointer to the last element in the slice.
- Returns an immutable pointer to the last element in the slice.
- Returns the number of elements in a slice.
- Creates a new slice from raw data.
- Creates a new slice from raw data without checking if
ptris null. - Returns the amount of bytes each value in a slice occupies.
- Creates a new slice from raw data.
- Creates a new slice from raw data without checking if
ptris null. - Returns the amount of bytes each value in a slice occupies.
Type Aliases
- Represents an optional value of type
NSTDSlice. - Represents an optional value of type
NSTDSliceMut.