#[repr(C)]pub struct NSTDSlice { /* private fields */ }Available on crate feature
nstd_core only.Expand description
An immutable view into a sequence of values in memory.
Safety
The user of this structure must ensure that the pointed-to data remains valid and unmodified while an instance of this structure is in use.