Struct nstd_sys::core::slice::NSTDSliceMut
source · #[repr(C)]pub struct NSTDSliceMut { /* private fields */ }Available on crate feature
nstd_core only.Expand description
A view into a sequence of values in memory.
Safety
The user of this structure must ensure that the pointed-to data remains valid, unmodified, and unreferenced in any other code while an instance of this structure is in use, else data races may occur.