#[repr(C)]pub struct NSTDStr { /* private fields */ }Available on crate feature
nstd_core only.Expand description
An immutable unowned view into a UTF-8 encoded byte string.
Safety
The user of this structure must ensure that the pointed-to data remains valid UTF-8, and unmodified while an instance of this structure is in use.