Struct nstd_sys::core::str::NSTDStrMut
source · #[repr(C)]pub struct NSTDStrMut { /* private fields */ }Available on crate feature
nstd_core only.Expand description
An unowned view into a UTF-8 encoded byte string.
Safety
The user of this structure must ensure that the pointed-to data remains valid UTF-8, unmodified, and unreferenced in any other code while an instance of this structure is in use, else data races may occur.