#[no_mangle]
pub extern "C" fn nstd_cstring_clone<'a>(
    cstring: &NSTDCString<'a>
) -> NSTDOptionalCString<'a>
Available on crate feature cstring only.
Creates a deep copy of an NSTDCString.

Parameters:

  • const NSTDCString *cstring - The C string to create a deep copy of.

Returns

NSTDOptionalCString cloned - A new deep copy of cstring on success, or an uninitialized “none” variant if allocating fails.