Function nstd_sys::env::nstd_env_args

source ·
#[no_mangle]
pub extern "C" fn nstd_env_args() -> NSTDVec<'static>
Available on crate feature nstd_env only.
Returns an NSTDVec of NSTDStrings that each represent an argument received at program start.

Returns

NSTDVec args - The NSTDString arguments that the program was started with.

Panics

This operation will panic if any program arguments contain invalid Unicode.