Function nstd_sys::env::nstd_env_current_dir
source · #[no_mangle]
pub extern "C" fn nstd_env_current_dir(
) -> NSTDIOStringResult<'static>Available on crate feature
nstd_env only.Expand description
Returns a complete path to the process’s current working directory.
Any non-Unicode sequences are replaced with the Unicode replacement character.
Returns
NSTDIOStringResult working_dir - A path to the current working directory on success, or the
I/O operation error code on failure.