Function nstd_sys::env::nstd_env_remove_var
source · #[no_mangle]
pub unsafe extern "C" fn nstd_env_remove_var(key: &NSTDStr)Available on crate feature
nstd_env only.Expand description
Removes an environment variable from the current process.
Parameters:
const NSTDStr *key- The environment variable’s identification key.
Panics
This operation will panic in the following situations:
-
keyis empty or contains either of the following ASCII characters:'='or'\0'. -
The environment variable’s value contains the ASCII null character
'\0'.
Safety
The user of this function must ensure that key is valid for reads.