#[no_mangle]
pub unsafe extern "C" fn nstd_env_set_current_dir(
    path: &NSTDStr
) -> NSTDIOError
Available on crate feature nstd_env only.
Sets the current working directory for the process.

Parameters:

  • const NSTDStr *path - The directory to set as the process working directory.

Returns

NSTDIOError errc - The I/O operation error code.

Safety

The user of this function must ensure that path is valid for reads.