Function nstd_sys::env::nstd_env_vars

source ·
#[no_mangle]
pub extern "C" fn nstd_env_vars() -> NSTDVec<'static>
Available on crate feature nstd_env only.
Returns an NSTDVec of NSTDString[2] which each represent an environment variable from the current process.

Returns

NSTDVec vars - A list of the process environment variables.

Panics

This operation will panic if any environment variables contain invalid Unicode.