Available on crate feature
fs only.Expand description
Provides access to the file system.
Modules
- A handle to an opened file.
Structs
- Represents file metadata.
Enums
- Describes the type of a file.
Constants
- A bit flag describing a file with read access.
Functions
- Returns the absolute path of a file system item.
- Copies the contents and permissions of one file to another.
- Creates a new directory on the file system.
- Recursively creates new directories on the file system.
- Creates a new file on the file system.
- Retrieves metadata about a file pointed to by
path. - Reads the contents of a file.
- Reads the contents of a file into a UTF-8 string.
- Removes a directory from the file system.
- Recursively removes directories on the file system.
- Removes a file from the file system.
- Renames a file or directory, replacing the destination if it already exists.
- Overwrites the contents of a file.
Type Aliases
- A result type returned from
nstd_fs_metadata.