Function nstd_sys::fs::nstd_fs_copy

source ·
#[no_mangle]
pub unsafe extern "C" fn nstd_fs_copy(
    from: &NSTDStr,
    to: &NSTDStr
) -> NSTDIOError
Available on crate feature fs only.
Copies the contents and permissions of one file to another.

Parameters:

  • const NSTDStr *from - The source file.

  • const NSTDStr *to - The destination file.

Returns

NSTDIOError errc - The I/O operation error code.

Safety

This operation can cause undefined behavior if either to or from’s data is invalid.