Available on crate feature
io only.Expand description
Provides functionality for interacting with the standard I/O streams.
Modules
- A handle to the standard error stream.
- A handle to the standard input stream.
- A handle to the standard output stream.
Enums
- An error type for I/O operations.
Functions
- Writes a string slice to stdout.
- Writes a string slice to stdout followed by a new line.
- Reads a line of UTF-8 input from stdin, discarding the newline character.
- Reads a line of UTF-8 input from stdin.
Type Aliases
- A result type that yields an NSTDVec on success and an I/O operation error code on failure.
- A result type that yields an NSTDUInt representing the number of bytes read or written by an I/O operation on success and an I/O operation error code on failure.
- A result type that yields a UTF-8 string on success and an I/O operation error code on failure.