NSTDIOError

Enum NSTDIOError 

#[repr(C)]
pub enum NSTDIOError {
Show 21 variants NSTD_IO_ERROR_NONE = 0, NSTD_IO_ERROR_UNKNOWN = 1, NSTD_IO_ERROR_NOT_FOUND = 2, NSTD_IO_ERROR_PERMISSION_DENIED = 3, NSTD_IO_ERROR_CONNECTION_REFUSED = 4, NSTD_IO_ERROR_CONNECTION_RESET = 5, NSTD_IO_ERROR_CONNECTION_TERMINATED = 6, NSTD_IO_ERROR_NO_CONNECTION = 7, NSTD_IO_ERROR_SOCKET_IN_USE = 8, NSTD_IO_ERROR_ADDRESS_NOT_FOUND = 9, NSTD_IO_ERROR_BROKEN_PIPE = 10, NSTD_IO_ERROR_ALREADY_EXISTS = 11, NSTD_IO_ERROR_BLOCKING = 12, NSTD_IO_ERROR_INVALID_INPUT = 13, NSTD_IO_ERROR_INVALID_DATA = 14, NSTD_IO_ERROR_TIMED_OUT = 15, NSTD_IO_ERROR_WRITE_ZERO = 16, NSTD_IO_ERROR_INTERRUPTED = 17, NSTD_IO_ERROR_UNSUPPORTED = 18, NSTD_IO_ERROR_UNEXPECTED_EOF = 19, NSTD_IO_ERROR_OUT_OF_MEMORY = 20,
}
Available on crate feature io only.
An error type for I/O operations.

Variants



NSTD_IO_ERROR_NONE = 0

No error occurred.



NSTD_IO_ERROR_UNKNOWN = 1

An unknown/other error occurred.



NSTD_IO_ERROR_NOT_FOUND = 2

An entity, such as a file, was not found.



NSTD_IO_ERROR_PERMISSION_DENIED = 3

Permission was denied.



NSTD_IO_ERROR_CONNECTION_REFUSED = 4

The connection was refused by a remote server.



NSTD_IO_ERROR_CONNECTION_RESET = 5

The connection was reset by a remote server.



NSTD_IO_ERROR_CONNECTION_TERMINATED = 6

The connection was terminated by a remote server.



NSTD_IO_ERROR_NO_CONNECTION = 7

There is no connection.



NSTD_IO_ERROR_SOCKET_IN_USE = 8

A socket address could not be used.



NSTD_IO_ERROR_ADDRESS_NOT_FOUND = 9

An address could not be found.



NSTD_IO_ERROR_BROKEN_PIPE = 10

The operation failed because a pipe was closed.



NSTD_IO_ERROR_ALREADY_EXISTS = 11

An entity, such as a file, already exists.



NSTD_IO_ERROR_BLOCKING = 12

The operation needs to block to complete.



NSTD_IO_ERROR_INVALID_INPUT = 13

Some input parameter was incorrect.



NSTD_IO_ERROR_INVALID_DATA = 14

Some input data was incorrect.



NSTD_IO_ERROR_TIMED_OUT = 15

The I/O operation’s timeout expired, causing it to be canceled.



NSTD_IO_ERROR_WRITE_ZERO = 16

Zero bytes were written to an output stream.



NSTD_IO_ERROR_INTERRUPTED = 17

The operation was interrupted.



NSTD_IO_ERROR_UNSUPPORTED = 18

The operation is unsupported on the current platform.



NSTD_IO_ERROR_UNEXPECTED_EOF = 19

A reader unexpectedly reached the end of a file.



NSTD_IO_ERROR_OUT_OF_MEMORY = 20

An operation could not be completed, because it failed to allocate enough memory.