Function nstd_sys::io::nstd_io_print
source · #[no_mangle]
pub unsafe extern "C" fn nstd_io_print(
output: &NSTDStr
) -> NSTDIOErrorAvailable on crate feature
io only.Expand description
Writes a string slice to stdout.
Parameters:
const NSTDStr *output- The string slice to write to stdout.
Returns
NSTDIOError errc - The I/O operation error code.
Safety
The provided string slice’s data must be valid, else this function can cause garbage bytes to be written to stdout.