Module stderr

Module stderr 

Available on crate feature io only.
A handle to the standard error stream.

Structs

NSTDStderr
A handle to the standard error stream.
NSTDStderrLock
A locked handle to the standard error stream.

Functions

nstd_io_stderr
Constructs a new handle to the standard error stream.
nstd_io_stderr_flush
Flushes the standard error stream.
nstd_io_stderr_free
Frees an instance of NSTDStderr.
nstd_io_stderr_lock
Constructs a new locked handle to the standard error stream.
nstd_io_stderr_lock_flush
Flushes the standard error stream.
nstd_io_stderr_lock_write
Writes some data to the standard error stream, returning how many bytes were written.
nstd_io_stderr_lock_write_all
Writes an entire buffer to the standard error stream.
nstd_io_stderr_unlock
Frees and unlocks an instance of NSTDStderrLock.
nstd_io_stderr_write
Writes some data to the standard error stream, returning how many bytes were written.
nstd_io_stderr_write_all
Writes an entire buffer to the standard error stream.

Type Aliases

NSTDOptionalStderr
Represents an optional value of type NSTDStderr.
NSTDOptionalStderrLock
Represents an optional value of type NSTDStderrLock.