#[no_mangle]
pub extern "C" fn nstd_io_stdin_lock() -> NSTDOptionalStdinLock
Available on crate feature io only.
Constructs a new locked handle to the standard input stream.

Returns

NSTDOptionalStdinLock handle - A locked handle to the standard input stream on success, or an uninitialized “none” variant on error.