Available on crate feature
io only.Expand description
A handle to the standard output stream.
Structs
- A handle to the standard output stream.
- A locked handle to the standard output stream.
Functions
- Constructs a new handle to the standard output stream.
- Flushes the standard output stream.
- Frees an instance of
NSTDStdout. - Constructs a new locked handle to the standard output stream.
- Flushes the standard output stream.
- Writes some data to the standard output stream.
- Writes an entire buffer to the standard output stream.
- Frees and unlocks an instance of
NSTDStdoutLock. - Writes some data to the standard output stream, returning how many bytes were written.
- Writes an entire buffer to the standard output stream.
Type Aliases
- Represents an optional value of type
NSTDStdout. - Represents an optional value of type
NSTDStdoutLock.