Function nstd_sys::io::stdout::nstd_io_stdout

source ·
#[no_mangle]
pub extern "C" fn nstd_io_stdout() -> NSTDOptionalStdout
Available on crate feature io only.
Constructs a new handle to the standard output stream.

Returns

NSTDOptionalStdout handle - A handle to the standard output stream on success, or an uninitialized “none” variant on error.