Function nstd_sys::io::stdout::nstd_io_stdout_lock
source · #[no_mangle]
pub extern "C" fn nstd_io_stdout_lock() -> NSTDOptionalStdoutLockAvailable on crate feature
io only.Expand description
Constructs a new locked handle to the standard output stream.
Returns
NSTDOptionalStdoutLock handle - A locked handle to the standard output stream on success, or
an uninitialized “none” variant on error.