Module nstd_sys::math

source ·
Available on crate feature nstd_math only.
High level math operations.

This library provides access to math functions that require the use of the “std” feature.

Functions

Returns the absolute value of x.
Returns the absolute value of x.
Computes the arccosine of x.
Computes the arccosine of x.
Computes the arcsine of x.
Computes the arcsine of x.
Computes the four quadrant arctangent of x & y.
Computes the four quadrant arctangent of x & y.
Computes the arctangent of x.
Computes the arctangent of x.
Rounds the value x up to the closest integral value.
Rounds the value x up to the closest integral value.
Computes the cosine of x.
Computes the cosine of x.
Computes the hyperbolic cosine of x.
Computes the hyperbolic cosine of x.
Rounds the value x down to the closest integral value.
Rounds the value x down to the closest integral value.
Raises x to an integral power.
Raises x to an integral power.
Computes the sine of x.
Computes the sine of x.
Computes the hyperbolic sine of x.
Computes the hyperbolic sine of x.
Computes the square root of x.
Computes the square root of x.
Computes the tangent of x.
Computes the tangent of x.
Computes the hyperbolic tangent of x.
Computes the hyperbolic tangent of x.