Function nstd_sys::math::nstd_math_ceil_f32
source · #[no_mangle]
pub extern "C" fn nstd_math_ceil_f32(x: NSTDFloat32) -> NSTDFloat32Available on crate feature
nstd_math only.Expand description
Rounds the value x up to the closest integral value.
Parameters:
NSTDFloat32 x- The value.
Returns
NSTDFloat32 value - The value rounded up to the nearest integral value.