Module os

Module os 

Available on crate feature os only.
Operating system specific functionality.

Modules

unixUnix
Low level Unix like operating system support.

Constants

NSTD_OS_ANDROIDNon-Android
Constant that is only set if the target operating system is Android.
NSTD_OS_BSDNeither DragonFly BSD nor FreeBSD nor NetBSD nor OpenBSD
Constant that is only set if the target operating system is BSD based.
NSTD_OS_DRAGONFLYNon-DragonFly BSD
Constant that is only set if the target operating system is DragonFly BSD.
NSTD_OS_FREEBSDNon-FreeBSD
Constant that is only set if the target operating system is FreeBSD.
NSTD_OS_HAIKUNon-Haiku
Constant that is only set if the target operating system is Haiku.
NSTD_OS_IOSNon-iOS
Constant that is only set if the target operating system is iOS.
NSTD_OS_LINUXLinux
Constant that is only set if the target operating system is Linux.
NSTD_OS_MACOSNon-macOS
Constant that is only set if the target operating system is macOS.
NSTD_OS_NETBSDNon-NetBSD
Constant that is only set if the target operating system is NetBSD.
NSTD_OS_NTONon-QNX Neutrino
Constant that is only set if the target operating system is QNX Neutrino.
NSTD_OS_OPENBSDNon-OpenBSD
Constant that is only set if the target operating system is OpenBSD.
NSTD_OS_SOLARISNon-Solaris
Constant that is only set if the target operating system is Solaris.
NSTD_OS_UNIXUnix
Constant that is only set if the target operating system is Unix based.
NSTD_OS_WINDOWSNon-Windows
Constant that is only set if the target operating system is Windows.