Available on crate features
os and os_unix_alloc only.Expand description
Memory allocation for Unix-like systems.
Enums
- Describes an error returned from an
nstd.os.unix.allocfunction.
Functions
- Allocates a block of memory on the heap, returning a pointer to it.
- Allocates a block of zero initialized memory on the heap, returning a pointer to it.
- Deallocates a block of memory previously allocated by
nstd_os_unix_alloc_allocate[_zeroed]. - Reallocates a block of memory previously allocated by
nstd_os_unix_alloc_allocate[_zeroed].