#[repr(C)]pub enum NSTDUnixIOError {
Show 16 variants
NSTD_UNIX_IO_ERROR_NONE = 0,
NSTD_UNIX_IO_ERROR_UNKNOWN = 1,
NSTD_UNIX_IO_ERROR_NOT_FOUND = 2,
NSTD_UNIX_IO_ERROR_PERMISSION_DENIED = 3,
NSTD_UNIX_IO_ERROR_CONNECTION_RESET = 4,
NSTD_UNIX_IO_ERROR_NO_CONNECTION = 5,
NSTD_UNIX_IO_ERROR_INVALID_SEEK = 6,
NSTD_UNIX_IO_ERROR_BROKEN_PIPE = 7,
NSTD_UNIX_IO_ERROR_BLOCKING = 8,
NSTD_UNIX_IO_ERROR_IS_DIR = 9,
NSTD_UNIX_IO_ERROR_INVALID_INPUT = 10,
NSTD_UNIX_IO_ERROR_INVALID_DATA = 11,
NSTD_UNIX_IO_ERROR_TIMED_OUT = 12,
NSTD_UNIX_IO_ERROR_INTERRUPTED = 13,
NSTD_UNIX_IO_ERROR_UNEXPECTED_EOF = 14,
NSTD_UNIX_IO_ERROR_OUT_OF_MEMORY = 15,
}os and os_unix_io only.Expand description
An error type for Unix I/O operations.
Variants
NSTD_UNIX_IO_ERROR_NONE = 0
No error occurred.
NSTD_UNIX_IO_ERROR_UNKNOWN = 1
An unknown error occurred.
NSTD_UNIX_IO_ERROR_NOT_FOUND = 2
An entity, such as a file, was not found.
NSTD_UNIX_IO_ERROR_PERMISSION_DENIED = 3
Permission was denied.
NSTD_UNIX_IO_ERROR_CONNECTION_RESET = 4
The connection was reset by a remote server.
NSTD_UNIX_IO_ERROR_NO_CONNECTION = 5
There is no connection.
NSTD_UNIX_IO_ERROR_INVALID_SEEK = 6
A seek operation failed because the file descriptor provided refers to a pipe, FIFO, or socket object.
NSTD_UNIX_IO_ERROR_BROKEN_PIPE = 7
The operation failed because a pipe was closed.
NSTD_UNIX_IO_ERROR_BLOCKING = 8
The operation needs to block to complete.
NSTD_UNIX_IO_ERROR_IS_DIR = 9
A pathname was expected to refer to a regular file, but a directory was found.
NSTD_UNIX_IO_ERROR_INVALID_INPUT = 10
Some input parameter was incorrect.
NSTD_UNIX_IO_ERROR_INVALID_DATA = 11
Some input/output data had an incorrect format.
NSTD_UNIX_IO_ERROR_TIMED_OUT = 12
The I/O operation’s timeout expired, causing it to be canceled.
NSTD_UNIX_IO_ERROR_INTERRUPTED = 13
The operation was interrupted.
NSTD_UNIX_IO_ERROR_UNEXPECTED_EOF = 14
A reader unexpectedly reached the end of a file.
NSTD_UNIX_IO_ERROR_OUT_OF_MEMORY = 15
An operation could not be completed, because it failed to allocate enough memory.