#[repr(C)]pub enum NSTDWindowsAllocError {
NSTD_WINDOWS_ALLOC_ERROR_NONE,
NSTD_WINDOWS_ALLOC_ERROR_OUT_OF_MEMORY,
NSTD_WINDOWS_ALLOC_ERROR_MEMORY_NOT_FOUND,
NSTD_WINDOWS_ALLOC_ERROR_HEAP_NOT_FOUND,
NSTD_WINDOWS_ALLOC_ERROR_INVALID_HEAP,
NSTD_WINDOWS_ALLOC_ERROR_INVALID_LAYOUT,
}Available on crate features
os and os_windows_alloc only.Expand description
Describes an error returned from allocation functions for Windows.
Variants
NSTD_WINDOWS_ALLOC_ERROR_NONE
No error occurred.
NSTD_WINDOWS_ALLOC_ERROR_OUT_OF_MEMORY
Allocating or reallocating failed.
NSTD_WINDOWS_ALLOC_ERROR_MEMORY_NOT_FOUND
Deallocating memory failed.
NSTD_WINDOWS_ALLOC_ERROR_HEAP_NOT_FOUND
Getting a handle to a heap failed.
NSTD_WINDOWS_ALLOC_ERROR_INVALID_HEAP
A heap is invalid.
NSTD_WINDOWS_ALLOC_ERROR_INVALID_LAYOUT
An allocation function received input parameters that resulted in an invalid memory layout.