Function nstd_sys::shared_lib::nstd_shared_lib_get
source · #[no_mangle]
pub unsafe extern "C" fn nstd_shared_lib_get(
lib: &NSTDSharedLib,
symbol: *const NSTDChar
) -> NSTDAnyAvailable on crate feature
shared_lib only.Expand description
Gets a pointer to a function or static variable in a dynamically loaded library by symbol name.
Parameters
-
const NSTDSharedLib *lib- The loaded library. -
const NSTDChar *symbol- The name of the function or variable to get a pointer to.
Returns
NSTDAny ptr - A pointer to the function or variable.
Safety
Undefined behavior may occur if symbol’s data is invalid.