Function nstd_sys::shared_lib::nstd_shared_lib_get_mut
source · #[no_mangle]
pub unsafe extern "C" fn nstd_shared_lib_get_mut(
lib: &mut NSTDSharedLib,
symbol: *const NSTDChar
) -> NSTDAnyMutAvailable on crate feature
shared_lib only.Expand description
Gets a mutable pointer to a function or static variable in a dynamically loaded library by symbol name.
Parameters
-
NSTDSharedLib *lib- The loaded library. -
const NSTDChar *symbol- The name of the function or variable to get a pointer to.
Returns
NSTDAnyMut ptr - A pointer to the function or variable.
Safety
Undefined behavior may occur if symbol’s data is invalid.