Function nstd_sys::shared_ptr::nstd_shared_ptr_free
source · #[no_mangle]
pub extern "C" fn nstd_shared_ptr_free(shared_ptr: NSTDSharedPtr)Available on crate feature
nstd_shared_ptr only.Expand description
Frees an instance of NSTDSharedPtr.
Parameters:
NSTDSharedPtr shared_ptr- The shared object to free.
Panics
Panics if there are no more shared pointers referencing the shared data and freeing the heap memory fails.