Available on crate feature
string only.Expand description
Dynamically sized UTF-8 encoded byte string.
Structs
- Dynamically sized UTF-8 encoded byte string.
Functions
- Returns an immutable reference to a string’s allocator.
- Returns an immutable byte slice of the string’s active data.
- Returns a raw pointer to a string’s memory.
- Creates a string slice containing the contents of
string. - Creates a string slice containing the contents of
string. - Returns the number of bytes a string contains.
- Returns a string’s capacity.
- Sets a string’s length to zero.
- Creates a deep copy of a string.
- Frees an instance of
NSTDString. - Creates a new string from owned UTF-8 data.
- Creates a new
NSTDStringfrom anNSTDFloat32. - Creates a new
NSTDStringfrom anNSTDFloat64. - Creates a new
NSTDStringfrom anNSTDInt8. - Creates a new
NSTDStringfrom anNSTDInt16. - Creates a new
NSTDStringfrom anNSTDInt32. - Creates a new
NSTDStringfrom anNSTDInt64. - Creates a new
NSTDStringfrom anNSTDInt. - Creates an owned version of an unowned string slice.
- Creates a new
NSTDStringfrom anNSTDUInt8. - Creates a new
NSTDStringfrom anNSTDUInt16. - Creates a new
NSTDStringfrom anNSTDUInt32. - Creates a new
NSTDStringfrom anNSTDUInt64. - Creates a new
NSTDStringfrom anNSTDUInt. - Returns ownership of an
NSTDString’s raw data, taking ownership of said string. - Returns the number of Unicode characters in a string.
- Creates a new instance of
NSTDString. - Creates a new string initialized with the given capacity.
- Removes the last character from a string and returns it.
- Pushes an
NSTDUnicharonto the end of a string. - Appends a string slice to the end of a string.
Type Aliases
- Represents an optional value of type
NSTDString.