Available on crate feature
thread only.Expand description
Thread spawning, joining, and detaching.
Structs
- Represents a running thread.
- Describes the creation of a new thread.
- A handle to a running thread.
- A thread’s unique identifier.
Functions
- Returns the number of recommended threads that a program should use.
- Returns a handle to the calling thread.
- Detaches a thread from it’s handle, allowing it to run in the background.
- Retrieves a raw handle to a thread.
- Frees an instance of
NSTDThreadHandle. - Returns a thread’s unique identifier.
- Compares two thread identifiers.
- Frees an instance of
NSTDThreadID. - Checks if a thread has finished running.
- Checks if the current thread is unwinding due to a panic.
- Joins a thread by it’s handle.
- Returns the name of a thread.
- Puts the current thread to sleep for a specified duration.
- Spawns a new thread executing the function
thread_fnand returns a handle to the new thread.
Type Aliases
- Represents an optional value of type
NSTDThread. - Represents an optional value of type
NSTDThreadHandle. - Represents an optional value of type
NSTDThreadID. - Returned from
nstd_thread_join, contains the thread function’s return value on success. - Returned from
nstd_thread_count, contains the number of threads detected on the system on success. - A thread function’s return value.