Function nstd_sys::thread::nstd_thread_count
source · #[no_mangle]
pub extern "C" fn nstd_thread_count() -> NSTDThreadCountResultAvailable on crate feature
thread only.Expand description
Returns the number of recommended threads that a program should use.
Returns
NSTDThreadCountResult threads - The estimated default amount of parallelism a program should
use on success, or the I/O error code on failure.