nstd_thread_is_panicking

Function nstd_thread_is_panicking 

#[unsafe(no_mangle)]
pub extern "C" fn nstd_thread_is_panicking() -> NSTDBool
Available on crate feature thread only.
Checks if the current thread is unwinding due to a panic.

Returns

NSTDBool is_panicking - Determines whether or not the calling thread is panicking.