#[no_mangle]
pub unsafe extern "C" fn nstd_thread_join(
    thread: NSTDThread
) -> NSTDOptionalThreadResult
Available on crate feature thread only.
Joins a thread by it’s handle.

Parameters:

  • NSTDThread thread - The thread handle.

Returns

NSTDOptionalThreadResult errc - The thread function’s return code, or none if joining the thread fails.

Safety

The data type that the thread function returns must be able to be safely sent between threads.