Function nstd_sys::thread::nstd_thread_sleep
source · #[no_mangle]
pub extern "C" fn nstd_thread_sleep(duration: NSTDDuration)Available on crate feature
thread only.Expand description
Puts the current thread to sleep for a specified duration.
Parameters:
NSTDDuration duration- The duration to put the thread to sleep for.
Panics
Panics if duration is negative, overflows Rust’s Duration structure, or is non-finite.