Module nstd_sys::timed_mutex
source · Available on crate feature
timed_mutex only.Expand description
A mutual exclusion primitive with a timed locking mechanism.
Functions
- Frees an instance of
NSTDTimedMutexafter invokingcallbackwith the mutex’s data. - Frees an instance of
NSTDTimedMutex. - Returns an immutable raw pointer to a timed mutex guard’s protected data.
- Returns an raw pointer to a timed mutex guard’s protected data.
- Consumes a timed mutex and returns the data it was protecting.
- Determines whether or not a timed mutex’s data is poisoned.
- Waits for a timed mutex lock to become acquired, returning a guard wrapping the protected data.
- Creates a new timed mutual exclusion primitive.
- The timed variant of
nstd_timed_mutex_lockreturning an uninitialized “none” result if the mutex lock could not be acquired after a specified number ofseconds. - The non-blocking variant of
nstd_timed_mutex_lockreturning an uninitialized “none” result if the mutex is locked by another thread. - Unlocks a timed mutex by consuming a mutex guard.
Type Aliases
- Represents an optional value of type
NSTDTimedMutex. - An optional value of type
NSTDTimedMutexLockResult. - A mutual exclusion primitive with a timed locking mechanism.
- A handle to a timed mutex’s data.
- A result type containing a timed mutex lock whether or not the mutex is poisoned.