Type Definition nstd_sys::NSTDAny

source ·
pub type NSTDAny = *const c_void;
A void pointer to some immutable data.

Safety

Accessing any data through this pointer type is unsafe. Raw pointers have no way of knowing if the data being pointed to is or isn’t valid.