Type Definition nstd_sys::NSTDAnyMut

source ·
pub type NSTDAnyMut = *mut c_void;
A void pointer (a pointer to some arbitrary type).

Safety

Accessing any data through this pointer type is unsafe. Raw pointers have no way of knowing if the data being pointed to is or isn’t valid.