Function nstd_sys::vec::nstd_vec_drop

source ·
#[no_mangle]
pub unsafe extern "C" fn nstd_vec_drop(
    vec: NSTDVec<'_>,
    callback: unsafe extern "C" fn(_: NSTDAnyMut)
)
Available on crate feature vec only.
Frees an instance of NSTDVec after invoking callback with each of the vector’s elements.

Parameters:

  • NSTDVec vec - The vector to free.

  • void (*callback)(NSTDAnyMut) - The vector data’s destructor.

Safety

This operation makes a direct call on a C function pointer (callback).