Function nstd_sys::vec::nstd_vec_end

source ·
#[no_mangle]
pub extern "C" fn nstd_vec_end(vec: &NSTDVec<'_>) -> NSTDAny
Available on crate feature vec only.
Returns a pointer to the end of a vector.

Note that this does not return a pointer to the last element or the last byte in the vector, but a pointer to one byte past the end of the vector’s active buffer.

Parameters:

  • const NSTDVec *vec - The vector.

Returns

NSTDAny end - A pointer to the end of the vector.