Module nstd_sys::alloc

source ·
Available on crate feature nstd_alloc only.
Low level memory allocation.

Enums

Describes an error returned from allocation functions.

Functions

Allocates a block of memory on the heap. The number of bytes to be allocated is specified by size.
Allocates a block of zero-initialized memory on the heap.
Deallocates a block of memory previously allocated by nstd_alloc_allocate[_zeroed].
Reallocates a block of memory previously allocated by nstd_alloc_allocate[_zeroed].