Module nstd_sys::core

source ·
Available on crate feature nstd_core only.
Provides core functionality for nstd.

The entire nstd.core module is dependency free and makes no use of Rust’s std library, making it fit for resource constrained/embedded environments.

Modules

  • Unowned C string slices.
  • Provides functions for examining and operating on character types.
  • Common types used throughout nstd.
  • Provides functions for examining and operating on floating point types.
  • Provides functions for examining and operating on integral types.
  • Low level math operations.
  • Contains mostly unsafe functions for interacting with raw memory.
  • Operator overloading for types and operators that may cause overflow.
  • Represents an optional (possibly uninitialized) value.
  • A sized pointer to some arbitrary type.
  • A numerical range.
  • Defines a “result” type with success and error variants.
  • A view into a sequence of values in memory.
  • An unowned view into a UTF-8 encoded byte string.
  • Low level time utilities.
  • A Unicode scalar value.

Functions