Module nstd_sys::core::math

source ·
Available on crate feature nstd_core only.
Low level math operations.

Functions

Computes the absolute (positive) value of x.
Computes the absolute (positive) value of x.
Computes the absolute (positive) value of x.
Computes the absolute (positive) value of x.
Computes the absolute (positive) value of x.
Clamps the value x to the bounds min and max.
Clamps the value x to the bounds min and max.
Clamps the value x to the bounds min and max.
Clamps the value x to the bounds min and max.
Clamps the value x to the bounds min and max.
Clamps the value x to the bounds min and max.
Clamps the value x to the bounds min and max.
Clamps the value x to the bounds min and max.
Clamps the value x to the bounds min and max.
Clamps the value x to the bounds min and max.
Clamps the value x to the bounds min and max.
Clamps the value x to the bounds min and max.
Converts radians to degrees.
Converts radians to degrees.
Divides two numbers and rounds the result up to the next integer.
Divides two numbers and rounds the result up to the next integer.
Divides two numbers and rounds the result up to the next integer.
Divides two numbers and rounds the result up to the next integer.
Divides two numbers and rounds the result up to the next integer.
Divides two numbers and rounds the result up to the next integer.
Divides two numbers and rounds the result up to the next integer.
Divides two numbers and rounds the result up to the next integer.
Divides two numbers and rounds the result up to the next integer.
Divides two numbers and rounds the result up to the next integer.
Divides two numbers and rounds the result down to the next integer.
Divides two numbers and rounds the result down to the next integer.
Divides two numbers and rounds the result down to the next integer.
Divides two numbers and rounds the result down to the next integer.
Divides two numbers and rounds the result down to the next integer.
Divides two numbers and rounds the result down to the next integer.
Divides two numbers and rounds the result down to the next integer.
Divides two numbers and rounds the result down to the next integer.
Divides two numbers and rounds the result down to the next integer.
Divides two numbers and rounds the result down to the next integer.
Raises the value x to the power of exp
Raises the value x to the power of exp
Raises the value x to the power of exp
Raises the value x to the power of exp
Raises the value x to the power of exp
Raises the value x to the power of exp
Raises the value x to the power of exp
Raises the value x to the power of exp
Raises the value x to the power of exp
Raises the value x to the power of exp
Converts degrees to radians.
Converts degrees to radians.