Available on crate feature
core only.Expand description
Contains mostly unsafe functions for interacting with raw memory.
Functions
- Compares two memory buffers of
numbytes. - Copies
numbytes fromsrctodest. - Copies
numbytes fromsrctodest. Unlikenstd_core_mem_copythis operation can be used when the two memory buffers overlap. - Fills the memory buffer
bufwith bytefill. - Iterates through each byte in a raw memory buffer until
delimis reached, returning a pointer to the delimiter byte if it is found. - Swaps
numbytes between the memory buffersxandy. - Zeros out a memory buffer.