Available on crate feature
nstd_core only.Expand description
Contains mostly unsafe functions for interacting with raw memory.
Functions
Compares two memory buffers of
num bytes.Copies
num bytes from src to dest.Copies
num bytes from src to dest. Unlike nstd_core_mem_copy this operation can be used
when the two memory buffers overlap.Fills the memory buffer
buf with byte fill.Iterates through each byte in a raw memory buffer until
delim is reached, returning a pointer
to the delimiter byte if it is found.Swaps
num bytes between the memory buffers x and y.Zeros out a memory buffer.