Module nstd_sys::core::ops

source ·
Available on crate feature nstd_core only.
Operator overloading for types and operators that may cause overflow.

The types of overflows that this module attempts to catch can be found here.

Also see this issue for more information.

Functions

Computes the addition operation of x + y.
Computes the addition operation of x + y.
Computes the addition operation of x + y.
Computes the addition operation of x + y.
Computes the addition operation of x + y.
Computes the addition operation of x + y.
Computes the addition operation of x + y.
Computes the addition operation of x + y.
Computes the addition operation of x + y.
Computes the addition operation of x + y.
Computes the addition operation of x + y.
Computes the addition operation of x + y.
Decrements x by 1.
Decrements x by 1.
Decrements x by 1.
Decrements x by 1.
Decrements x by 1.
Decrements x by 1.
Decrements x by 1.
Decrements x by 1.
Decrements x by 1.
Decrements x by 1.
Decrements x by 1.
Decrements x by 1.
Computes the division operation of x / y.
Computes the division operation of x / y.
Computes the division operation of x / y.
Computes the division operation of x / y.
Computes the division operation of x / y.
Computes the division operation of x / y.
Computes the division operation of x / y.
Computes the division operation of x / y.
Computes the division operation of x / y.
Computes the division operation of x / y.
Computes the division operation of x / y.
Computes the division operation of x / y.
Increments x by 1.
Increments x by 1.
Increments x by 1.
Increments x by 1.
Increments x by 1.
Increments x by 1.
Increments x by 1.
Increments x by 1.
Increments x by 1.
Increments x by 1.
Increments x by 1.
Increments x by 1.
Computes the multiplication operation of x * y.
Computes the multiplication operation of x * y.
Computes the multiplication operation of x * y.
Computes the multiplication operation of x * y.
Computes the multiplication operation of x * y.
Computes the multiplication operation of x * y.
Computes the multiplication operation of x * y.
Computes the multiplication operation of x * y.
Computes the multiplication operation of x * y.
Computes the multiplication operation of x * y.
Computes the multiplication operation of x * y.
Computes the multiplication operation of x * y.
Returns the negative value of x.
Returns the negative value of x.
Returns the negative value of x.
Returns the negative value of x.
Returns the negative value of x.
Returns the negative value of x.
Returns the negative value of x.
Computes the remainder of x / y.
Computes the remainder of x / y.
Computes the remainder of x / y.
Computes the remainder of x / y.
Computes the remainder of x / y.
Computes the remainder of x / y.
Computes the remainder of x / y.
Computes the remainder of x / y.
Computes the remainder of x / y.
Computes the remainder of x / y.
Computes the remainder of x / y.
Computes the remainder of x / y.
Shifts value x y bits to the left.
Shifts value x y bits to the left.
Shifts value x y bits to the left.
Shifts value x y bits to the left.
Shifts value x y bits to the left.
Shifts value x y bits to the left.
Shifts value x y bits to the left.
Shifts value x y bits to the left.
Shifts value x y bits to the left.
Shifts value x y bits to the left.
Shifts value x y bits to the right.
Shifts value x y bits to the right.
Shifts value x y bits to the right.
Shifts value x y bits to the right.
Shifts value x y bits to the right.
Shifts value x y bits to the right.
Shifts value x y bits to the right.
Shifts value x y bits to the right.
Shifts value x y bits to the right.
Shifts value x y bits to the right.
Computes the subtraction operation of x - y.
Computes the subtraction operation of x - y.
Computes the subtraction operation of x - y.
Computes the subtraction operation of x - y.
Computes the subtraction operation of x - y.
Computes the subtraction operation of x - y.
Computes the subtraction operation of x - y.
Computes the subtraction operation of x - y.
Computes the subtraction operation of x - y.
Computes the subtraction operation of x - y.
Computes the subtraction operation of x - y.
Computes the subtraction operation of x - y.