Module nstd_sys::core::ptr

source ·
Available on crate feature nstd_core only.
A sized pointer to some arbitrary type.

Structs

A sized immutable pointer to some arbitrary type.
A sized pointer to some arbitrary type.

Functions

Returns a raw immutable pointer to the object pointed to by ptr.
Creates an immutable version of a mutable pointer.
Returns a raw pointer to the object pointed to by ptr.
Returns a raw immutable pointer to the object pointed to by ptr.
Creates a new instance of NSTDPtrMut.
Returns the size of the object being pointed to.
Writes data from obj to ptr. The number of bytes written is determined by ptr.size.
Creates a new instance of NSTDPtr.
Returns the size of the object being pointed to.