Available on crate feature
nstd_core only.Expand description
Provides useful utilities for working with raw pointers.
Functions
- Returns a pointer that is properly aligned to
alignbased on the offsetptr. - Returns a pointer that is properly aligned to
alignbased on the offsetptr. - Creates a new dangling immutable pointer with valid alignment for any scalar type.
- Creates a new dangling mutable pointer with valid alignment for any scalar type.
- Checks if
ptris aligned toalign.