Available on crate feature
nstd_core only.Expand description
An unowned view into a UTF-8 encoded byte string.
Structs
An immutable unowned view into a UTF-8 encoded byte string.
An unowned view into a UTF-8 encoded byte string.
Functions
Returns an immutable byte slice over
str’s data.Returns a raw pointer to a string slice’s memory.
Returns the number of bytes a string slice contains.
Creates a string slice from raw bytes.
Creates a string slice from raw bytes, without checking for UTF-8.
Creates a new instance of an
NSTDStr from a C string slice.Creates a new instance of an
NSTDStr from a C string slice.Creates a new
NSTDStr from a raw C string.Creates a new
NSTDStr from a raw C string, including the null byte.Gets the
NSTDUnichar at index pos in str.Returns the number of Unicode characters in a string slice.
Returns an immutable byte slice over
str’s data.Creates an immutable version of a mutable string slice.
Returns an immutable raw pointer to a string slice’s memory.
Returns the number of bytes a string slice contains.
Creates a string slice from raw bytes.
Creates a string slice from raw bytes, without checking for UTF-8.
Creates a new instance of an
NSTDStrMut from a C string slice.Creates a new instance of an
NSTDStrMut from a C string slice.Creates a new
NSTDStrMut from a raw C string.Creates a new
NSTDStrMut from a raw C string, including the null byte.Gets the
NSTDUnichar at index pos in str.Returns the number of Unicode characters in a string slice.
Creates a substring of an existing string slice.
Attempts to parse a string slice as an
NSTDFloat32.Attempts to parse a string slice as an
NSTDFloat64.Attempts to parse a string slice as an
NSTDInt8.Attempts to parse a string slice as an
NSTDInt16.Attempts to parse a string slice as an
NSTDInt32.Attempts to parse a string slice as an
NSTDInt64.Attempts to parse a string slice as an
NSTDInt.Attempts to parse a string slice as an
NSTDUInt8.Attempts to parse a string slice as an
NSTDUInt16.Attempts to parse a string slice as an
NSTDUInt32.Attempts to parse a string slice as an
NSTDUInt64.Attempts to parse a string slice as an
NSTDUInt.Creates a substring of an existing string slice.
Attempts to parse a string slice as an
NSTDFloat32.Attempts to parse a string slice as an
NSTDFloat64.Attempts to parse a string slice as an
NSTDInt8.Attempts to parse a string slice as an
NSTDInt16.Attempts to parse a string slice as an
NSTDInt32.Attempts to parse a string slice as an
NSTDInt64.Attempts to parse a string slice as an
NSTDInt.Attempts to parse a string slice as an
NSTDUInt8.Attempts to parse a string slice as an
NSTDUInt16.Attempts to parse a string slice as an
NSTDUInt32.Attempts to parse a string slice as an
NSTDUInt64.Attempts to parse a string slice as an
NSTDUInt.