Module nstd_sys::cstring

source ·
Available on crate feature nstd_cstring only.
A dynamically sized, null terminated, C string.

Structs

A dynamically sized, null terminated, C string.

Functions

Returns an immutable byte slice of the C string’s active data, including the null byte.
Creates a C string slice containing the contents of cstring.
Creates a C string slice containing the contents of cstring.
Returns a raw pointer to a C string’s memory.
Returns a C string’s capacity.
Sets a C string’s length to zero.
Creates a deep copy of an NSTDCString.
Frees an instance of NSTDCString.
Creates an owned version of an unowned C string slice.
Returns ownership of an NSTDCString’s raw data, taking ownership of said C string.
Returns the number of chars in a C string, excluding the null terminator.
Returns the number of chars in a C string, including the null terminator.
Creates a new empty NSTDCString.
Creates a new NSTDCString initialized with the given capacity.
Removes the last character from a C string and returns it.
Appends an NSTDChar to the end of an NSTDCString.
Appends a C string slice to the end of a C string.