#[no_mangle]
pub extern "C" fn nstd_cstring_clone(
    cstring: &NSTDCString
) -> NSTDCString
Available on crate feature nstd_cstring only.
Creates a deep copy of an NSTDCString.

Parameters:

  • const NSTDCString *cstring - The C string to create a deep copy of.

Returns

NSTDCString cloned - A new deep copy of cstring.

Panics

This function will panic if allocating for the new C string fails.