Function nstd_sys::cstring::nstd_cstring_clone
source · #[no_mangle]
pub extern "C" fn nstd_cstring_clone(
cstring: &NSTDCString
) -> NSTDCStringAvailable on crate feature
nstd_cstring only.Expand description
Creates a deep copy of an NSTDCString.
Parameters:
const NSTDCString *cstring- The C string to create a deep copy of.
Returns
NSTDCString cloned - A new deep copy of cstring.
Panics
This function will panic if allocating for the new C string fails.