Function nstd_sys::env::nstd_env_set_current_dir
source · #[no_mangle]
pub unsafe extern "C" fn nstd_env_set_current_dir(
path: &NSTDStr
) -> NSTDIOErrorAvailable on crate feature
nstd_env only.Expand description
Sets the current working directory for the process.
Parameters:
const NSTDStr *path- The directory to set as the process working directory.
Returns
NSTDIOError errc - The I/O operation error code.
Safety
The user of this function must ensure that path is valid for reads.