Available on crate feature
nstd_fs only.Expand description
Provides access to the file system.
Modules
A handle to an opened file.
Functions
Writes the absolute path of a file system item to
out_buf. This will initially clear
out_buf.Copies the contents and permissions of one file to another.
Creates a new directory on the file system.
Recursively creates new directories on the file system.
Creates a new file on the file system.
Extends a vector with the contents of a file.
Extends a string with the contents of a file.
Removes a directory from the file system.
Recursively removes directories on the file system.
Removes a file from the file system.
Renames a file or directory, replacing the destination if it already exists.
Overwrites the contents of a file.