Function nstd_sys::fs::nstd_fs_metadata
source · #[no_mangle]
pub unsafe extern "C" fn nstd_fs_metadata(
path: &NSTDStr
) -> NSTDFileMetadataResultAvailable on crate feature
nstd_fs only.Expand description
Retrieves metadata about a file pointed to by path.
Parameters:
const NSTDStr *path- A path to the file to retrieve metadata for.
Returns
NSTDFileMetadataResult metadata - Metadata describing the file.
Safety
path must be valid for reads.