Available on crate feature
nstd_heap_ptr only.Expand description
A pointer type for single value heap allocation.
Structs
A pointer type for single value heap allocation.
Functions
Creates a clone of a heap allocated object.
Frees an instance of
NSTDHeapPtr.Returns an immutable raw pointer to the object on the heap.
Returns a raw pointer to the object on the heap.
Creates a new initialized heap allocated object.
Creates a new zero-initialized heap allocated object.
Returns the size of the heap allocated object.