Module nstd_sys::io

source ·
Available on crate feature nstd_io only.
Provides functionality for interacting with the standard I/O streams.

Modules

A handle to the standard error stream.
A handle to the standard input stream.
A handle to the standard output stream.

Enums

An error type for I/O operations.

Functions

Writes a string slice to stdout.
Writes a string slice to stdout followed by a new line.
Reads a line of UTF-8 input from stdin and pushes it onto buffer without the newline.
Reads a line of UTF-8 input from stdin and pushes it onto buffer.