Enum nstd_sys::io::NSTDIOError

source ·
#[repr(C)]
pub enum NSTDIOError {
Show 21 variants NSTD_IO_ERROR_NONE, NSTD_IO_ERROR_UNKNOWN, NSTD_IO_ERROR_NOT_FOUND, NSTD_IO_ERROR_PERMISSION_DENIED, NSTD_IO_ERROR_CONNECTION_REFUSED, NSTD_IO_ERROR_CONNECTION_RESET, NSTD_IO_ERROR_CONNECTION_TERMINATED, NSTD_IO_ERROR_NO_CONNECTION, NSTD_IO_ERROR_SOCKET_IN_USE, NSTD_IO_ERROR_ADDRESS_NOT_FOUND, NSTD_IO_ERROR_BROKEN_PIPE, NSTD_IO_ERROR_ALREADY_EXISTS, NSTD_IO_ERROR_BLOCKING, NSTD_IO_ERROR_INVALID_INPUT, NSTD_IO_ERROR_INVALID_DATA, NSTD_IO_ERROR_TIMED_OUT, NSTD_IO_ERROR_WRITE_ZERO, NSTD_IO_ERROR_INTERRUPTED, NSTD_IO_ERROR_UNSUPPORTED, NSTD_IO_ERROR_UNEXPECTED_EOF, NSTD_IO_ERROR_OUT_OF_MEMORY,
}
Available on crate feature nstd_io only.
An error type for I/O operations.

Variants

NSTD_IO_ERROR_NONE

No error occurred.

NSTD_IO_ERROR_UNKNOWN

An unknown/other error occurred.

NSTD_IO_ERROR_NOT_FOUND

An entity, such as a file, was not found.

NSTD_IO_ERROR_PERMISSION_DENIED

Permission was denied.

NSTD_IO_ERROR_CONNECTION_REFUSED

The connection was refused by a remote server.

NSTD_IO_ERROR_CONNECTION_RESET

The connection was reset by a remote server.

NSTD_IO_ERROR_CONNECTION_TERMINATED

The connection was terminated by a remote server.

NSTD_IO_ERROR_NO_CONNECTION

There is no connection.

NSTD_IO_ERROR_SOCKET_IN_USE

A socket address could not be used.

NSTD_IO_ERROR_ADDRESS_NOT_FOUND

An address could not be found.

NSTD_IO_ERROR_BROKEN_PIPE

The operation failed because a pipe was closed.

NSTD_IO_ERROR_ALREADY_EXISTS

An entity, such as a file, already exists.

NSTD_IO_ERROR_BLOCKING

The operation needs to block to complete.

NSTD_IO_ERROR_INVALID_INPUT

Some input parameter was incorrect.

NSTD_IO_ERROR_INVALID_DATA

Some input data was incorrect.

NSTD_IO_ERROR_TIMED_OUT

The I/O operation’s timeout expired, causing it to be canceled.

NSTD_IO_ERROR_WRITE_ZERO

Zero bytes were written to an output stream.

NSTD_IO_ERROR_INTERRUPTED

The operation was interrupted.

NSTD_IO_ERROR_UNSUPPORTED

The operation is unsupported on the current platform.

NSTD_IO_ERROR_UNEXPECTED_EOF

A reader unexpectedly reached the end of a file.

NSTD_IO_ERROR_OUT_OF_MEMORY

An operation could not be completed, because it failed to allocate enough memory.