Available on crate feature
nstd_io only.Expand description
A handle to the standard error stream.
Functions
Constructs a new handle to the standard error stream.
Flushes the standard error stream.
Frees an instance of
NSTDStderr.Writes some data to the standard error stream, setting
written to the number of bytes
written.Writes an entire buffer to the standard error stream.
Type Definitions
A handle to the standard error stream.