Module nstd_sys::io::stdin

source ·
Available on crate feature nstd_io only.
A handle to the standard input stream.

Functions

Constructs a new handle to the standard input stream.
Frees an instance of NSTDStdin.
Reads some data from stdin into a byte slice buffer.
Continuously reads data from stdin into a buffer until EOF is reached.
Reads enough data from stdin to fill the entirety of buffer.
Reads a line from stdin and appends it to buffer.
Continuously reads UTF-8 data from stdin into a string buffer until EOF is reached.

Type Definitions

A handle to the standard input stream.