Function nstd_sys::io::stdin::nstd_io_stdin
source · #[no_mangle]
pub extern "C" fn nstd_io_stdin() -> NSTDOptionalStdinAvailable on crate feature
io only.Expand description
Constructs a new handle to the standard input stream.
Returns
NSTDOptionalStdin handle - A handle to the standard input stream on success, or an
uninitialized “none” variant on error.