Function nstd_sys::io::stdin::nstd_io_stdin_lock
source · #[no_mangle]
pub extern "C" fn nstd_io_stdin_lock() -> NSTDOptionalStdinLockAvailable on crate feature
io only.Expand description
Constructs a new locked handle to the standard input stream.
Returns
NSTDOptionalStdinLock handle - A locked handle to the standard input stream on success, or an
uninitialized “none” variant on error.