Available on crate feature
nstd_io only.Expand description
A handle to the standard output stream.
Functions
Constructs a new handle to the standard output stream.
Flushes the standard output stream.
Frees an instance of
NSTDStdout.Writes some data to the standard output stream, setting
written to the number of bytes
written.Writes an entire buffer to the standard output stream.
Type Definitions
A handle to the standard output stream.