Function nstd_sys::io::stdout::nstd_io_stdout_write_all
source · #[no_mangle]
pub unsafe extern "C" fn nstd_io_stdout_write_all(
handle: &mut NSTDStdout,
bytes: &NSTDSlice
) -> NSTDIOErrorAvailable on crate feature
io only.Expand description
Writes an entire buffer to the standard output stream.
Note
This function will return an error code of NSTD_IO_ERROR_INVALID_INPUT if the slice’s element
size is not 1.
Parameters:
-
NSTDStdout *handle- A handle to stdout. -
const NSTDSlice *bytes- The data to be written to stdout.
Returns
NSTDIOError errc - The I/O operation error code.
Safety
This function can cause undefined behavior if bytes’s data is invalid.