Function nstd_sys::math::nstd_math_floor_f64
source · #[no_mangle]
pub extern "C" fn nstd_math_floor_f64(x: NSTDFloat64) -> NSTDFloat64Available on crate feature
math only.Expand description
Rounds the value x down to the closest integral value.
Parameters:
NSTDFloat64 x- The value.
Returns
NSTDFloat64 value - The value rounded down to the nearest integral value.