Function nstd_sys::mutex::nstd_mutex_drop
source · #[no_mangle]
pub unsafe extern "C" fn nstd_mutex_drop(
mutex: NSTDMutex<'_>,
callback: unsafe extern "C" fn(_: NSTDAnyMut)
)Available on crate feature
nstd_mutex only.Expand description
Frees an instance of NSTDMutex after invoking callback with the mutex’s data.
callback will not be called if the mutex is poisoned.
Parameters:
-
NSTDMutex mutex- The mutex to free. -
void (*callback)(NSTDAnyMut)- The mutex data’s destructor.
Safety
This operation makes a direct call on a C function pointer (callback).