Module nstd_sys::os

source ·
Available on crate feature os only.
Operating system specific functionality.

Modules

  • Low level Unix like operating system support.

Constants

  • Constant that is only set if the target operating system is Linux.
  • Constant that is only set if the target operating system is Unix based.