#[repr(C)]pub enum NSTDUnixIOError {
Show 16 variants
NSTD_UNIX_IO_ERROR_NONE,
NSTD_UNIX_IO_ERROR_UNKNOWN,
NSTD_UNIX_IO_ERROR_NOT_FOUND,
NSTD_UNIX_IO_ERROR_PERMISSION_DENIED,
NSTD_UNIX_IO_ERROR_CONNECTION_RESET,
NSTD_UNIX_IO_ERROR_NO_CONNECTION,
NSTD_UNIX_IO_ERROR_INVALID_SEEK,
NSTD_UNIX_IO_ERROR_BROKEN_PIPE,
NSTD_UNIX_IO_ERROR_BLOCKING,
NSTD_UNIX_IO_ERROR_IS_DIR,
NSTD_UNIX_IO_ERROR_INVALID_INPUT,
NSTD_UNIX_IO_ERROR_INVALID_DATA,
NSTD_UNIX_IO_ERROR_TIMED_OUT,
NSTD_UNIX_IO_ERROR_INTERRUPTED,
NSTD_UNIX_IO_ERROR_UNEXPECTED_EOF,
NSTD_UNIX_IO_ERROR_OUT_OF_MEMORY,
}os and os_unix_io only.Expand description
An error type for Unix I/O operations.
Variants
NSTD_UNIX_IO_ERROR_NONE
No error occurred.
NSTD_UNIX_IO_ERROR_UNKNOWN
An unknown error occurred.
NSTD_UNIX_IO_ERROR_NOT_FOUND
An entity, such as a file, was not found.
NSTD_UNIX_IO_ERROR_PERMISSION_DENIED
Permission was denied.
NSTD_UNIX_IO_ERROR_CONNECTION_RESET
The connection was reset by a remote server.
NSTD_UNIX_IO_ERROR_NO_CONNECTION
There is no connection.
NSTD_UNIX_IO_ERROR_INVALID_SEEK
A seek operation failed because the file descriptor provided refers to a pipe, FIFO, or socket object.
NSTD_UNIX_IO_ERROR_BROKEN_PIPE
The operation failed because a pipe was closed.
NSTD_UNIX_IO_ERROR_BLOCKING
The operation needs to block to complete.
NSTD_UNIX_IO_ERROR_IS_DIR
A pathname was expected to refer to a regular file, but a directory was found.
NSTD_UNIX_IO_ERROR_INVALID_INPUT
Some input parameter was incorrect.
NSTD_UNIX_IO_ERROR_INVALID_DATA
Some input/output data had an incorrect format.
NSTD_UNIX_IO_ERROR_TIMED_OUT
The I/O operation’s timeout expired, causing it to be canceled.
NSTD_UNIX_IO_ERROR_INTERRUPTED
The operation was interrupted.
NSTD_UNIX_IO_ERROR_UNEXPECTED_EOF
A reader unexpectedly reached the end of a file.
NSTD_UNIX_IO_ERROR_OUT_OF_MEMORY
An operation could not be completed, because it failed to allocate enough memory.