Module nstd_sys::shared_ptr
source · Available on crate feature
nstd_shared_ptr only.Expand description
A reference counting smart pointer.
Structs
A reference counting smart pointer.
Functions
Frees an instance of
NSTDSharedPtr.Returns an immutable raw pointer to the shared object.
Creates a new initialized instance of a shared pointer.
Creates a new zero-initialized instance of a shared pointer.
Returns the number of pointers that share
shared_ptr’s data.Shares
shared_ptr.Returns the size of the shared object.