Available on crate feature
nstd_string only.Expand description
Dynamically sized UTF-8 encoded byte string.
Structs
Dynamically sized UTF-8 encoded byte string.
Functions
Returns an immutable byte slice of the string’s active data.
Returns a raw pointer to a string’s memory.
Creates a string slice containing the contents of
string.Creates a string slice containing the contents of
string.Returns the number of bytes a string contains.
Returns a string’s capacity.
Sets a string’s length to zero.
Creates a deep copy of a string.
Frees an instance of
NSTDString.Creates a new
NSTDString from an NSTDFloat32.Creates a new
NSTDString from an NSTDFloat64.Creates a new
NSTDString from an NSTDInt8.Creates a new
NSTDString from an NSTDInt16.Creates a new
NSTDString from an NSTDInt32.Creates a new
NSTDString from an NSTDInt64.Creates a new
NSTDString from an NSTDInt.Creates an owned version of an unowned string slice.
Creates a new
NSTDString from an NSTDUInt8.Creates a new
NSTDString from an NSTDUInt16.Creates a new
NSTDString from an NSTDUInt32.Creates a new
NSTDString from an NSTDUInt64.Creates a new
NSTDString from an NSTDUInt.Returns ownership of an
NSTDString’s raw data, taking ownership of said string.Returns the number of Unicode characters in a string.
Creates a new instance of
NSTDString.Creates a new string initialized with the given capacity.
Removes the last character from a string and returns it.
Pushes an
NSTDUnichar onto the end of a string.Appends a string slice to the end of a string.