Available on crate feature
nstd_thread only.Expand description
Thread spawning, joining, and detaching.
Structs
- Describes the creation of a new thread.
Functions
- Returns the number of recommended threads that a program should use.
- Returns a handle to the calling thread.
- Detaches a thread from it’s handle, allowing it to run in the background.
- Retrieves a raw handle to a thread.
- Frees an instance of
NSTDThreadHandle. - Returns a thread’s unique identifier.
- Compares two thread identifiers.
- Frees an instance of
NSTDThreadID. - Checks if a thread has finished running.
- Checks if the current thread is unwinding due to a panic.
- Joins a thread by it’s handle.
- Returns the name of a thread.
- Puts the current thread to sleep for a specified duration.
- Spawns a new thread and returns a handle to it.
- Spawns a new thread configured with a descriptor.
Type Definitions
- Returned from
nstd_thread_join, contains the thread function’s return value on success. - Represents a running thread.
- Returned from
nstd_thread_count, contains the number of threads detected on the system on success. - A handle to a running thread.
- A thread’s unique identifier.
- A thread function’s return value.