#[unsafe(no_mangle)]pub extern "C" fn nstd_thread_is_panicking() -> NSTDBoolAvailable on crate feature
thread only.Expand description
Checks if the current thread is unwinding due to a panic.
Returns
NSTDBool is_panicking - Determines whether or not the calling thread is panicking.