Function nstd_sys::time::nstd_time_get
source · #[no_mangle]
pub extern "C" fn nstd_time_get(time: NSTDTime) -> NSTDFloat64Available on crate feature
nstd_time only.Expand description
Returns the number of seconds stored in an NSTDTime object as an NSTDFloat64.
Parameters:
NSTDTime time- The time object.
Returns
NSTDFloat64 seconds - The number of seconds in a time object represented as an
NSTDFloat64.