Type Definition nstd_sys::NSTDAnyMut
source · Expand description
A void pointer (a pointer to some arbitrary type).
Safety
Accessing any data through this pointer type is unsafe. Raw pointers have no way of knowing if the data being pointed to is or isn’t valid.