Function nstd_sys::vec::nstd_vec_end_mut
source · #[no_mangle]
pub extern "C" fn nstd_vec_end_mut(
vec: &mut NSTDVec<'_>
) -> NSTDAnyMutAvailable on crate feature
vec only.Expand description
Returns a mutable pointer to the end of a vector.
Note that this does not return a pointer to the last element or the last byte in the vector, but a pointer to one byte past the end of the vector’s active buffer.
Parameters:
NSTDVec *vec- The vector.
Returns
NSTDAnyMut end - A mutable pointer to the end of the vector.